{% extends 'base.html' %}

{% block title %}Data sources{% endblock %}

{% block content %}
    <p>
    <a href="{% url 'datasource-new' %}?TSURU_TOKEN={{ request.token }}">new</a>
    </p>
    <ul>
      {% for item in list %}
      <li>{{ item.Name }} - {{ item.Method }} on {{ item.URL }} <a href="{% url 'datasource-get' item.Name %}?TSURU_TOKEN={{ request.token }}">view details</a></li>
      {% endfor %}
    </ul>
{% endblock %}
